@@ -87,7 +87,8 @@ def connect_epics(prefix):
 
     PARAMETERS
 
-    prefix (str):
+    prefix
+        *str* :
         EPICS PV prefix
     """
     from .apsbss_ophyd import EpicsBssDevice
@@ -112,7 +113,8 @@ def epicsClear(prefix):
 
     PARAMETERS
 
-    prefix (str):
+    prefix
+        *str* :
         EPICS PV prefix
     """
     logger.debug("clear EPICS %s", prefix)
@@ -133,7 +135,8 @@ def epicsUpdate(prefix):
 
     PARAMETERS
 
-    prefix (str):
+    prefix
+        *str* :
         EPICS PV prefix
     """
     logger.debug("update EPICS %s", prefix)
@@ -189,10 +192,10 @@ def epicsUpdate(prefix):
             obj.email.put(user["email"])
             obj.first_name.put(user["firstName"])
             obj.last_name.put(user["lastName"])
-            obj.number_users_in_pvs.put(i+1)
+            bss.esaf.number_users_in_pvs.put(i+1)
             if i == 8:
                 break
-        obj.number_users_total.put(len(esaf["experimentUsers"]))
+        bss.esaf.number_users_total.put(len(esaf["experimentUsers"]))
 
     if len(proposal_id) > 0:
         bss.status_msg.put(f"get Proposal {proposal_id} from APS ...")
@@ -224,10 +227,10 @@ def epicsUpdate(prefix):
             obj.institution_id.put(str(user["instId"]))
             obj.user_id.put(str(user["id"]))
             obj.pi_flag.put(user.get("piFlag") in ("Y", "y"))
-            obj.number_users_in_pvs.put(i+1)
+            bss.proposal.number_users_in_pvs.put(i+1)
             if i == 8:
                 break
-        obj.number_users_total.put(len(proposal["experimenters"]))
+        bss.proposal.number_users_total.put(len(proposal["experimenters"]))
 
     bss.status_msg.put("Done")
 
@@ -239,11 +242,14 @@ def epicsSetup(prefix, beamline, cycle=None):
 
     PARAMETERS
 
-    prefix (str):
+    prefix
+        *str* :
         EPICS PV prefix
-    beamline (str):
+    beamline
+        *str* :
         Name of beam line (as defined by the BSS)
-    cycle (str):
+    cycle
+        *str* :
         Name of APS run cycle (as defined by the BSS).
         optional: default is current APS run cycle name.
     """
@@ -281,7 +287,8 @@ def getCurrentEsafs(sector):
 
     PARAMETERS
 
-    sector (str or int):
+    sector
+        *str* or *int* :
         Name of sector.  If ``str``, must be in ``%02d`` format (``02``, not ``2``).
     """
     if isinstance(sector, int):
@@ -306,7 +313,8 @@ def getCurrentInfo(beamline):
 
     PARAMETERS
 
-    beamline (str):
+    beamline
+        *str* :
         Name of beam line (as defined by the BSS).
     """
     sector = beamline.split("-")[0]
@@ -343,7 +351,8 @@ def getCurrentProposals(beamline):
 
     PARAMETERS
 
-    beamline (str):
+    beamline
+        *str* :
         Name of beam line (as defined by the BSS).
     """
     proposals = []
@@ -361,7 +370,8 @@ def getEsaf(esafId):
 
     PARAMETERS
 
-    esafId (int):
+    esafId
+        *int* :
         ESAF number
     """
     try:
@@ -377,11 +387,14 @@ def getProposal(proposalId, cycle, beamline):
 
     PARAMETERS
 
-    proposalId (str):
+    proposalId
+        *str* :
         Proposal identification number
-    cycle (str):
+    cycle
+        *str* :
         Name of APS run cycle (as defined by the BSS)
-    beamline (str):
+    beamline
+        *str* :
         Name of beam line (as defined by the BSS)
     """
     # avoid possible dm.DmException
@@ -408,10 +421,11 @@ def iso2datetime(isodate):
 
     PARAMETERS
 
-    isodate (str):
-        Date and time in ISO8601 format. (e.g.: ``2020-07-01T12:34:56.789012``)
+    isodate
+        *str* :
+        Date and time in modified ISO8601 format. (e.g.: ``2020-07-01 12:34:56.789012``)
     """
-    return datetime.datetime.fromisoformat(isodate)
+    return datetime.datetime.strptime(isodate, "%Y-%m-%d %H:%M:%S.%f")
 
 
 def listAllBeamlines():
@@ -440,7 +454,8 @@ def listRecentRuns(quantity=6):
 
     PARAMETERS
 
-    quantity (int):
+    quantity
+        *int* :
         number of APS run cycles to include, optional (default: 6)
     """
     # 6 runs is the duration of a user proposal
@@ -459,11 +474,14 @@ def printColumns(items, numColumns=5, width=10):
 
     PARAMETERS
 
-    items (list(str)):
+    items
+        *[str]* :
         List of items to report
-    numColumns (int):
+    numColumns
+        *int* :
         number of columns, optional (default: 5)
-    width (int):
+    width
+        *int* :
         width of each column, optional (default: 10)
     """
     n = len(items)
@@ -489,9 +507,11 @@ def trim(text, length=40):
 
     PARAMETERS
 
-    text (str):
+    text
+        *str* :
         String, potentially longer than ``length``
-    length (int):
+    length
+        *int* :
         maximum length, optional (default: 40)
     """
     if length < 1:
@@ -570,13 +590,15 @@ def get_options():
 
     return parser.parse_args()
 
+
 def cmd_cycles(args):
     """
     Handle ``cycles`` command.
 
     PARAMETERS
 
-    args (obj):
+    args
+        *obj* :
         Object returned by ``argparse``
     """
     if args.full:
@@ -593,23 +615,25 @@ def cmd_cycles(args):
                 entry["name"],
                 entry["startTime"],
                 entry["endTime"], ))
-        logger.debug("%s", str(table))
+        print(str(table))
     else:
         printColumns(listAllRuns())
 
+
 def cmd_current(args):
     """
     Handle ``current`` command.
 
     PARAMETERS
 
-    args (obj):
+    args
+        *obj* :
         Object returned by ``argparse``
     """
     records = getCurrentProposals(args.beamlineName)
     tNow = datetime.datetime.now().isoformat(sep=" ")
     if len(records) == 0:
-        logger.debug("No current proposals for %s", args.beamlineName)
+        print(f"No current proposals for {args.beamlineName}")
     else:
         def prop_sorter(prop):
             return prop["startTime"]
@@ -630,14 +654,14 @@ def cmd_current(args):
                     item["endTime"],
                     users,
                     trim(item["title"]),))
-        logger.debug(
-            "Current (and Future) Proposal(s) on %s: %s\n\n%s",
-            args.beamlineName, tNow, str(table))
+        print(
+            "Current (and Future) Proposal(s) on"
+            f" {args.beamlineName}: {tNow}\n\n{table}")
 
     sector = args.beamlineName.split("-")[0]
     records = getCurrentEsafs(sector)
     if len(records) == 0:
-        logger.debug("No current ESAFs for sector %s", sector)
+        print(f"No current ESAFs for sector {sector}")
     else:
         def esaf_sorter(prop):
             return prop["experimentStartDate"]
@@ -659,9 +683,9 @@ def cmd_current(args):
                 users,
                 trim(item["esafTitle"], 40),
                 ))
-        logger.debug(
-            "Current (and Future) ESAF(s) on sector %s: %s\n\n%s",
-            sector, tNow, str(table))
+        print(
+            "Current (and Future) ESAF(s) on sector"
+            f" {sector}: {tNow}\n\n{table}")
 
 
 def cmd_esaf(args):
@@ -670,16 +694,17 @@ def cmd_esaf(args):
 
     PARAMETERS
 
-    args (obj):
+    args
+        *obj* :
         Object returned by ``argparse``
     """
     try:
         esaf = getEsaf(args.esafId)
-        logger.debug("%s", yaml.dump(esaf))
+        print(yaml.dump(esaf))
     except DmRecordNotFound as exc:
-        logger.debug("%s", exc)
+        print(exc)
     except dm.DmException as exc:
-        logger.debug("dm reported: %s", exc)
+        print("dm reported: {exc}")
 
 
 def cmd_proposal(args):
@@ -688,16 +713,17 @@ def cmd_proposal(args):
 
     PARAMETERS
 
-    args (obj):
+    args
+        *obj* :
         Object returned by ``argparse``
     """
     try:
         proposal = getProposal(args.proposalId, args.cycle, args.beamlineName)
-        logger.debug("%s", yaml.dump(proposal))
+        print(yaml.dump(proposal))
     except DmRecordNotFound as exc:
-        logger.debug("%s", exc)
+        print(exc)
     except dm.DmException as exc:
-        logger.debug("dm reported: %s", exc)
+        print("dm reported: {exc}")
 
 
 def cmd_report(args):
@@ -706,7 +732,8 @@ def cmd_report(args):
 
     PARAMETERS
 
-    args (obj):
+    args
+        *obj* :
         Object returned by ``argparse``
     """
     from ..utils import object_explorer
